import java.util.ArrayList;
import java.util.Scanner;
import java.util.HashSet;
import java.util.HashMap;

class Edge {
	String node1;
	String node2;
	Edge(String n1, String n2) {
		node1 = n1;
		node2 = n2;
	}
}

public class WeakestMicrobot {

	/* Return -1 if the first one is less dense, 0 if they are equal, and 1 if the second one is less dense. */
	private static int compareDensities(int numEdges1, int degree1, int numEdges2, int degree2) {
		if( (numEdges1 == 0) || (numEdges2 == 0) ) {
			if( (numEdges1 == 0) && (numEdges2 == 0)) {
				// if both are zero, decide depending on the degree
				if(degree1 == degree2) return 0;
				return degree1 > degree2 ? -1 : 1;
			}
			return (numEdges1 == 0) ? -1 : 1;
		}

		// Note: degree1 or degree2 cannot be 1 at this time (degree = 1 => numEdges = 0)
		double density1 = 2.0 * numEdges1 / (degree1 * (degree1 - 1));
		double density2 = 2.0 * numEdges2 / (degree2 * (degree2 - 1));

		if(Math.abs(density1 - density2) < 0.0001) {
			return 0;
		} else {
			return density1 < density2 ? -1 : 1;
		}
	}

	private static String solveWeakestMicrobot(ArrayList<Edge> edges)
	{
		/* ------------------- INSERT CODE HERE ---------------------
		 *
		 * For a node, define local_density = count(how many edges among its neighbors)/count(how many possible edges among its neighbors)
		 *
		 * Find the node with the least local density. Assume no nodes with 0 neighbors.
		 *
		 * */

		HashMap<String, HashSet<String>> neighbors = new HashMap<String, HashSet<String>>();

		for(Edge e : edges) {
			HashSet<String> hs = neighbors.get(e.node1);
			if(hs == null) {
				hs = new HashSet<String>(); 
				neighbors.put(e.node1, hs);
			} 
			hs.add(e.node2);

			hs = neighbors.get(e.node2);
			if(hs == null) {
				hs = new HashSet<String>(); 
				neighbors.put(e.node2, hs);
			} 
			hs.add(e.node1);
		}

		// for(String s: neighbors.keySet()) {
			// System.out.println(s + " neighbors = " + neighbors.get(s));
		// }

		int minEdgesSoFar = 200; // the initial constants don't matter
		int minDegreeSoFar = 10;
		String min = null;
		for(String s : neighbors.keySet()) {
			HashSet<String> hs = neighbors.get(s);

			// iterate
			int count = 0;
			for(String s1 : hs) {
				for(String s2 : hs) {
					if(s1.compareTo(s2) < 0) {
						// check if edge exists
						if(neighbors.get(s1).contains(s2)) {
							count++;
						}
					}
				}
			}

			// System.out.println("The number of edges for " + s + " is " + count);

			int comp = compareDensities(count, hs.size(), minEdgesSoFar, minDegreeSoFar);

			if( (min == null) || (comp == -1) || ( (comp == 0) && (s.compareTo(min) < 0) ) ) {
				minEdgesSoFar = count; minDegreeSoFar = hs.size(); min = s;
			} 
		}

		return min;
		/* -------------------- END OF INSERTION --------------------*/
	}

	public static void main(String[] args) {
		Scanner sc = new Scanner(System.in);

		int numTests = sc.nextInt();		// number of test cases

		for (int t = 0; t < numTests; t++) {
			int numEdges = sc.nextInt();
			ArrayList<Edge> edges = new ArrayList<Edge>();

			for(int i = 0; i < numEdges; i++) 
				edges.add(new Edge(sc.next(), sc.next()));

			System.out.println("The lexicographically first microbot with the weakest neighborhood is " + solveWeakestMicrobot(edges));
		}

		sc.close();
	}
}
