import java.awt.Point;
import java.util.Scanner;


public class SignPostI {
	static class Square{
		String direction; 
		int number;

		Square(String direction, int number) {
			this.direction = direction;
			this.number = number;
		}
		Square(int number, String direction) {
			this.direction = direction;
			this.number = number;
		}
		public String toString(){
			return ""+String.format("%02d", number)+" "+direction;
		}
	}
	
	// Determine how to augment the row/col dimensions to move in a certain cardinal direction
	public static Point getRowColIncrement(String sign){
		int rowIncrement=0, colIncrement=0;
		if (sign.equals("N")) {
			rowIncrement = -1;
		} else if (sign.equals("S")) {
			rowIncrement = 1;
		} else if (sign.equals("E")) {
			colIncrement = 1;
		} else if (sign.equals("W")) {
			colIncrement = -1;
		} else {
			throw new RuntimeException("Invalid signpost direction: "+sign);
		}
		return new Point(rowIncrement, colIncrement);
	}
	
	//  Create a deep copy of a puzzle
	public static Square[][] copyPuzzle(Square[][] puzzle){
		//
		int rows = puzzle.length;
		int cols = puzzle[0].length;
		Square[][] rval = new Square[rows][cols];
		for(int r=0;r<rows;r++)
			for(int c=0;c<cols;c++)
				rval[r][c] = new Square(puzzle[r][c].direction,puzzle[r][c].number);
		return rval;
	}
	
	//  Check whether the given coordinates are within the bounds of an nxn array
	public static boolean isInBounds(int r, int c, int n){
		return r>=0 && r<n && c>=0 && c<n;
	}
	
	//  PUT YOUR CODE HERE
	public static int solveSignPostI(Square[][] puzzle){
		int n = puzzle.length;
		//  solution must begin in upper left corner
		if(puzzle[0][0].number!=1)
			return 1;
		int row = 0;
		int col = 0;
		puzzle[row][col].number = -1; // mark this cell as visited
		//  Check that each number between 1 and n*n appears exactly once, and that number are arranged in a valid way
		for(int i=1;i<n*n;i++){
			Point inc = getRowColIncrement(puzzle[row][col].direction);
			//  Loop over all cells in the search direction
			while(isInBounds(row+=inc.x, col+=inc.y, n)){
				if(puzzle[row][col].number == i+1)	//  break when we find the next integer
					break;
			}
			if(!isInBounds(row, col, n)) //  If the next integer was never found, the solution is invalid
				return i+1;
			puzzle[row][col].number = -1; // mark this cell as visited
		}
		return -1; // the puzzle solution is valid
	}
	
	public static Square[][] readPuzzle(Scanner sc){
		int puzzSize = sc.nextInt();
		// Read a puzzSize * puzzSize * 2 array of entries and instantiate the Squares array
		Square[][] puzzle = new Square[puzzSize][puzzSize];
		for(int i = 0; i < puzzSize; i++)  {
			for(int j = 0; j < puzzSize; j++)  {
				puzzle[i][j] = new Square(sc.nextInt(), sc.next());
			}
		}
		return puzzle;
	}
	
	public static void writePuzzle(Square[][] puzz){
		// Write a puzzle to a buffer in text format
		System.out.print(""+puzz.length+"\n");
		for(Square[] row : puzz)  {
			for(Square sq : row)  {
				System.out.print(sq.toString()+"  ");
			}
			System.out.println();
		}
	}
	
	public static void main(String[] args){
		Scanner sc = new Scanner(System.in);

		//  Read in each puzzle, solve it, and write results to output
		
		int numPuzzles = sc.nextInt();  //  the first line contains the number of puzzles in the file

		for(int n = 0; n < numPuzzles; n++){
			Square[][] puzzle = readPuzzle(sc);

			// Solve the puzzle using YOUR routine
			int isValid = solveSignPostI(puzzle);

			if(isValid < 0)
				System.out.println("The solution is valid");
			else
				System.out.println("The solution is invalid, and the first incorrect number is " + isValid);
		}		
	}
}
