import java.util.ArrayList;
import java.util.Collections;
import java.util.Scanner;


public class MinFlip {
	
	/* Given an array of coin positions & instructions on which range of
	 * coins to flip each time, calculate the resulting coin positions
	 * as an array.
	 * 
	 * For instance, given coins = [HHH], flip = [1 1][1 3],
	 * first flip coins from positions 1 to 1, yielding [THH],
	 * then flip coins from positions 1 to 3, yielding [HTT].
	 */
	
    private static char[][] flipCoins(char coins[], int flip[][]) {

    	int numFlips = flip.length; /* number of flips */
    	
    	/* allocate storage for solution */
    	char result[][] = new char[numFlips][];
    		
     	for (int i=0; i<numFlips; i++) { 		

    		if (i == 0) 
    			result[i] = coins.clone();
    		else
    			result[i] = result[i-1].clone();
    			
    		for (int j=flip[i][0]; j<=flip[i][1]; j++) {
    			if (result[i][j-1] == 'H')
    				result[i][j-1] = 'T';
    			else
    				result[i][j-1] = 'H';
    		}
     	}
    		    	
        return result;

    }
    
    /* generate next flip sequence to try given current flip sequence */
    /* based on lexicographic order, if range X,Y then Y >= X */
    /* E.g., [1,1]->[1,2]->[1,3], [1,n]->[2,2]->[2,3], [n,n]->[1,1][1,1] */
    
    private static int[][] genFlipSeq(int size, int flips[][]) {
    	int seqLen = flips.length;
    	
    	for (int i=1; i<=seqLen; i++) {
    		if (flips[seqLen - i][1] < size) {
    			flips[seqLen - i][1]++;
    			return flips;
    		}
    		if (flips[seqLen - i][0] < size) {
    			flips[seqLen - i][0]++;
    			flips[seqLen - i][1] = flips[seqLen - i][0];
    			return flips;
    		}
    		/* reset to [1,1] since will be bumping up more significant digit */
			flips[seqLen - i][0] = 1;
			flips[seqLen - i][1] = 1;

    	}
    	
    	if (seqLen == size)		/* out of sequences to try */
    		return null;
    	
    	int result[][] = new int[seqLen+1][2];
    	
    	for (int i=0; i<seqLen+1; i++) {
    		result[i][0] = 1;
    		result[i][1] = 1;
    	}

    	return result;
    
    }
    
    /* check whether char array is all heads */
    private static boolean allHeads(char coins[]) {
		int size = coins.length;
		
		/* if already all H, no flips are necessary */
		for (int i=0; i<size; i++) {
			if (coins[i] != 'H')
				return false;
		}
		return true;
    }
    
    /* convert sequence of flips saved as char[][] into a String */
    private static String buildString(char coins[][]) {
		String seq = "";
		int numFlip = coins.length;
		for (int j=0; j<numFlip; j++) {
			seq = seq + new String(coins[j]) + " ";
		}
		return seq;
    }
    
    /* Given a String of coin positions, find all minimal length
     * sequences of flips that result in all heads. For each sequence,
     * show the coin positions separated by spaces. Return all sequences 
     * in an ArrayList<String>, which will be sorted by alphabetical order
     * before being output. No flips should be returned if coins are
     * initially all heads.
     * 
     * For instance, given [TTT] return [HHH]. [HHH] returns empty ArrayList.
     */
    
    private static ArrayList<String> findMinFlip(String board) {
		char coins[] = board.toCharArray();
		ArrayList<String> soln = new ArrayList<String>();
		
		if (allHeads(coins))	/* no flips needed */
			return soln;
		
		int size = coins.length;
    	int minFlipNum = Integer.MAX_VALUE;
    	
    	int flip[][] = new int[1][2];	/* starting flip sequence */
    	flip[0][0] = 1;
    	flip[0][1] = 1;
    	
    	while (flip != null) {		
			char result[][] = flipCoins(coins, flip);
			
			int numFlip = flip.length;
			if (numFlip > minFlipNum)	/* longer than prev min solution */
				return soln;
			
			if (allHeads(result[numFlip-1])) {
				String seq = buildString(result);
				soln.add(seq);				/* save solution as String */
				if (minFlipNum > numFlip)	/* update length of best solution */
					minFlipNum = numFlip;
			}
			
			/* try next flip sequence */
    		flip = genFlipSeq(size, flip);
    	}
    	return soln;
    }

    /*
    private static void printFlips(int flip[][]) {
    	System.err.printf("Flips = ");
    	int size = flip.length;
    	for (int i=0; i<size; i++) {
    		System.err.printf("%d-%d ", flip[i][0], flip[i][1]);
    	}
    	System.err.println();
    }
    */
    
	public static void main(String[] args) {
		Scanner sc = new Scanner(System.in);

		int numOfTestCases = sc.nextInt();

		for (int testCase=0; testCase < numOfTestCases; testCase++) {
			String board = sc.next();
			
			ArrayList<String> soln = findMinFlip(board);
			System.out.printf("Coins %s \n", board);
			Collections.sort(soln);
			for (String s : soln) 
				System.out.printf("%s %s \n", board, s.trim());
		}
		
		sc.close();
	}
}

