import java.awt.Point;
import java.util.ArrayList;
import java.util.Scanner;


public class SignPostII {
	static class Square{
		String direction; 
		int number;

		Square(String direction, int number) {
			this.direction = direction;
			this.number = number;
		}
		Square(int number, String direction) {
			this.direction = direction;
			this.number = number;
		}
		public String toString(){
			return ""+String.format("%02d", number)+" "+direction;
		}
	}
	
	// Determine how to augment the row/col dimensions to move in a certain cardinal direction
	public static Point getRowColIncrement(String sign){
		int rowIncrement=0, colIncrement=0;
		if (sign.equals("N")) {
			rowIncrement = -1;
		} else if (sign.equals("S")) {
			rowIncrement = 1;
		} else if (sign.equals("E")) {
			colIncrement = 1;
		} else if (sign.equals("W")) {
			colIncrement = -1;
		} else {
			throw new RuntimeException("Invalid signpost direction: "+sign);
		}
		return new Point(rowIncrement, colIncrement);
	}
	
	//  Create a deep copy of a puzzle
	public static Square[][] copyPuzzle(Square[][] puzzle){
		//
		int rows = puzzle.length;
		int cols = puzzle[0].length;
		Square[][] rval = new Square[rows][cols];
		for(int r=0;r<rows;r++)
			for(int c=0;c<cols;c++)
				rval[r][c] = new Square(puzzle[r][c].direction,puzzle[r][c].number);
		return rval;
	}
	
	//  Check whether the given coordinates are within the bounds of an nxn array
	public static boolean isInBounds(int r, int c, int n){
		return r>=0 && r<n && c>=0 && c<n;
	}
	
	//  PUT YOUR CODE HERE
	public static Square[][] solveSignPostII(Square[][] puzzle){
		puzzle[0][0].number = 1;
		puzzle = solveSignPostII_recursive(puzzle, 0, 0);
		return puzzle;
	}
	
	// A helper method that performs recursion to solve a signpost problem
	public static Square[][] solveSignPostII_recursive(Square[][] puzzle, int startRow, int startCol){
		//  Problem size
		int n = puzzle.length;
		//  How many squares have been filled in?
		int moveNumber = puzzle[startRow][startCol].number+1;
		//  Which direction does the current sign point
		String startSign = puzzle[startRow][startCol].direction;
		//  If n*n moves have been made, then the puzzle has been solved and the solution is complete!
		if(moveNumber>n*n){
			return puzzle;
		}
		Point inc = getRowColIncrement(startSign);
		// Loop over the valid squares, and try moving into every square.  
		// Recursively call this method to see if the resulting move makes the board solvable.
		for(int r=startRow, c=startCol;
				isInBounds(r, c, n);
				r+=inc.x, c+=inc.y){
			if(puzzle[r][c].number>0)	// If this square has already been used, then move on
				continue;
			Square[][] trial = copyPuzzle(puzzle);
			trial[r][c].number = moveNumber;
			trial = solveSignPostII_recursive(trial, r, c); //  recursive call
			if(trial!=null)		//  If this move generated a solution, then return the solution.
				return trial;
		}
		//  If not solution was not found, then return null.  
		//  The current board configuration is not solvable.
		return null;
	}
	
	
	public static Square[][] readPuzzle(Scanner sc){
		int puzzSize = sc.nextInt();
		// Read a puzzSize * puzzSize * 2 array of entries and instantiate the Squares array
		Square[][] puzzle = new Square[puzzSize][puzzSize];
		for(int i = 0; i < puzzSize; i++)  {
			for(int j = 0; j < puzzSize; j++)  {
				puzzle[i][j] = new Square(sc.nextInt(), sc.next());
			}
		}
		return puzzle;
	}
	
	public static void writePuzzle(Square[][] puzz){
		// Write a puzzle to a buffer in text format
		System.out.print(""+puzz.length+"\n");
		for(Square[] row : puzz)  {
			for(Square sq : row)  {
				System.out.print(sq.toString()+"  ");
			}
			System.out.println();
		}
	}
	
	public static void main(String[] args){
		Scanner sc = new Scanner(System.in);

		//  Read in each puzzle from the input file, solve it, and write results to output
		
		int numPuzzles = sc.nextInt();  //  the first line contains the number of puzzles in the file

		System.out.println("" + numPuzzles);

		for(int n = 0; n < numPuzzles; n++){
			Square[][] puzzle = readPuzzle(sc);
			// Solve the puzzle using YOUR routine
			puzzle = solveSignPostII(puzzle);
			// Record results to output file
			writePuzzle(puzzle);
		}
		sc.close();
	}
}
